pub struct Position {
pub lat: f64,
pub lng: f64,
}Expand description
A struct to represent a position on the map.
This allows to pass the positions around even on the server side, since LatLng is a client-side only struct.
This struct offers some utility methods to work with positions, and conversions to LatLng. It also supports passing positions as tuples or arrays.
Fields
lat: f64lng: f64Implementations
Sourceimpl Position
impl Position
Sourcepub fn distance_haversine(&self, other: &Self) -> f64
pub fn distance_haversine(&self, other: &Self) -> f64
Determines the distance between two positions using the Haversine formula.
The result is in meters
Sourcepub fn inside_circle(&self, center: &Position, radius: f64) -> bool
pub fn inside_circle(&self, center: &Position, radius: f64) -> bool
Checks if the position is inside a circle
Arguments
center: Center of the circleradius: Radius of the circle in meters
returns: bool
Sourcepub fn inside_polygon(&self, polygon: &[Position]) -> bool
pub fn inside_polygon(&self, polygon: &[Position]) -> bool
Check if the position is inside a polygon
Sourcepub fn distance(&self, other: &Self) -> f64
pub fn distance(&self, other: &Self) -> f64
Distance between two positions using pytagore theorem
pub fn as_lat_lng(&self) -> LatLng