pub struct ThreadSafeJsValue<T> { /* private fields */ }Expand description
A wrapper around a value that is intended to be passed between threads.
The main use is to wrap JsValue based objects that are not Send or Sync. There is a small overhead to check if the value is on the current thread.
Implementations
Sourceimpl<T> ThreadSafeJsValue<T>
impl<T> ThreadSafeJsValue<T>